compare_dist: Compare Distributions

Description Usage Arguments Details Value Examples

Description

The purpose of this plot is to search for outliers/errors/typos in client-specific H-data values.

Usage

1
compare_dist(newdata, var, mean, sd, binwidth)

Arguments

newdata

Dataframe downloaded from SPARS containing all assessments that you want to check. This will usually just include intakes.

var

H-data variable of interest

mean

(optional) mean of the distribution of the variable of interest

sd

(optional) standard deviation of the distribution of the variable of interest

binwidth

(optional) The binwidth of the plot

Details

Simulates a gamma distribution and compares client-specific H-data values to the simulated distribution.

If optional variables are not specified, the function will use a reference value.

Value

Histogram of simulated data with lines indicating client's actual H-data values.

Examples

1
compare_dist(newdata, var, mean, sd, binwidth)

sarahvanhala/nomscheck documentation built on May 11, 2019, 5:15 p.m.